summaryrefslogtreecommitdiffstats
path: root/kspread/kspread_pen.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /kspread/kspread_pen.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kspread/kspread_pen.h')
-rw-r--r--kspread/kspread_pen.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kspread/kspread_pen.h b/kspread/kspread_pen.h
index 81bc0229e..23de5877d 100644
--- a/kspread/kspread_pen.h
+++ b/kspread/kspread_pen.h
@@ -20,19 +20,19 @@
#ifndef KSPREADPEN_H
#define KSPREADPEN_H
-#include <qpen.h>
+#include <tqpen.h>
class KoZoomHandler;
/**
* Pen that handles line widths in points
*/
-class KSpreadPen : public QPen
+class KSpreadPen : public TQPen
{
public:
KSpreadPen();
- KSpreadPen(const QColor& _color, double _pointWidth, Qt::PenStyle _style);
- KSpreadPen(const QColor& _color);
+ KSpreadPen(const TQColor& _color, double _pointWidth, Qt::PenStyle _style);
+ KSpreadPen(const TQColor& _color);
~KSpreadPen();
/**
@@ -58,8 +58,8 @@ class KSpreadPen : public QPen
/// KSpreadPen width in points
double pointWidth() const { return m_pointWidth; }
- /// Returns a zoomed QPen
- QPen zoomedPen(KoZoomHandler* zoomHandler);
+ /// Returns a zoomed TQPen
+ TQPen zoomedPen(KoZoomHandler* zoomHandler);
private:
double m_pointWidth;